==> camel-k-crds-2.3.0-sources.jar: org/apache/camel/v1/IntegrationProfileStatus.java <==
package org.apache.camel.v1;

@com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
@com.fasterxml.jackson.annotation.JsonPropertyOrder({"build","conditions","kamelet","observedGeneration","phase","traits"})
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@javax.annotation.processing.Generated("io.fabric8.java.generator.CRGeneratorRunner")
@lombok.ToString()
@lombok.EqualsAndHashCode()
@io.sundr.builder.annotations.Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ObjectMeta.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ObjectReference.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.LabelSelector.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.Container.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.EnvVar.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ContainerPort.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.Volume.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.VolumeMount.class)
})
public class IntegrationProfileStatus implements io.fabric8.kubernetes.api.model.KubernetesResource {

    /**
     * specify how to build the Integration/IntegrationKits
     */
    @com.fasterxml.jackson.annotation.JsonProperty("build")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("specify how to build the Integration/IntegrationKits")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1.integrationprofilestatus.Build build;

    public org.apache.camel.v1.integrationprofilestatus.Build getBuild() {
        return build;
    }

    public void setBuild(org.apache.camel.v1.integrationprofilestatus.Build build) {
        this.build = build;
    }

    /**
     * which are the conditions met (particularly useful when in ERROR phase)
     */
    @com.fasterxml.jackson.annotation.JsonProperty("conditions")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("which are the conditions met (particularly useful when in ERROR phase)")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private java.util.List<org.apache.camel.v1.integrationprofilestatus.Conditions> conditions;

    public java.util.List<org.apache.camel.v1.integrationprofilestatus.Conditions> getConditions() {
        return conditions;
    }

    public void setConditions(java.util.List<org.apache.camel.v1.integrationprofilestatus.Conditions> conditions) {
        this.conditions = conditions;
    }

    /**
     * configuration to be executed to all Kamelets controlled by this IntegrationProfile
     */
    @com.fasterxml.jackson.annotation.JsonProperty("kamelet")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("configuration to be executed to all Kamelets controlled by this IntegrationProfile")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1.integrationprofilestatus.Kamelet kamelet;

    public org.apache.camel.v1.integrationprofilestatus.Kamelet getKamelet() {
        return kamelet;
    }

    public void setKamelet(org.apache.camel.v1.integrationprofilestatus.Kamelet kamelet) {
        this.kamelet = kamelet;
    }

    /**
     * ObservedGeneration is the most recent generation observed for this IntegrationProfile.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("observedGeneration")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("ObservedGeneration is the most recent generation observed for this IntegrationProfile.")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private Long observedGeneration;

    public Long getObservedGeneration() {
        return observedGeneration;
    }

    public void setObservedGeneration(Long observedGeneration) {
        this.observedGeneration = observedGeneration;
    }

    /**
     * defines in what phase the IntegrationProfile is found
     */
    @com.fasterxml.jackson.annotation.JsonProperty("phase")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("defines in what phase the IntegrationProfile is found")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private String phase;

    public String getPhase() {
        return phase;
    }

    public void setPhase(String phase) {
        this.phase = phase;
    }

    /**
     * list of traits to be executed for all the Integration/IntegrationKits built from this IntegrationProfile
     */
    @com.fasterxml.jackson.annotation.JsonProperty("traits")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("list of traits to be executed for all the Integration/IntegrationKits built from this IntegrationProfile")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1.integrationprofilestatus.Traits traits;

    public org.apache.camel.v1.integrationprofilestatus.Traits getTraits() {
        return traits;
    }

    public void setTraits(org.apache.camel.v1.integrationprofilestatus.Traits traits) {
        this.traits = traits;
    }
}

==> camel-k-crds-2.4.0-sources.jar: org/apache/camel/v1/IntegrationProfileStatus.java <==
package org.apache.camel.v1;

@com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
@com.fasterxml.jackson.annotation.JsonPropertyOrder({"build","conditions","kamelet","observedGeneration","phase","traits"})
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@javax.annotation.processing.Generated("io.fabric8.java.generator.CRGeneratorRunner")
@lombok.ToString()
@lombok.EqualsAndHashCode()
@io.sundr.builder.annotations.Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ObjectMeta.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ObjectReference.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.LabelSelector.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.Container.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.EnvVar.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ContainerPort.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.Volume.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.VolumeMount.class)
})
public class IntegrationProfileStatus implements io.fabric8.kubernetes.api.builder.Editable<IntegrationProfileStatusBuilder>, io.fabric8.kubernetes.api.model.KubernetesResource {

    @java.lang.Override
    public IntegrationProfileStatusBuilder edit() {
        return new IntegrationProfileStatusBuilder(this);
    }

    /**
     * specify how to build the Integration/IntegrationKits
     */
    @com.fasterxml.jackson.annotation.JsonProperty("build")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("specify how to build the Integration/IntegrationKits")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1.integrationprofilestatus.Build build;

    public org.apache.camel.v1.integrationprofilestatus.Build getBuild() {
        return build;
    }

    public void setBuild(org.apache.camel.v1.integrationprofilestatus.Build build) {
        this.build = build;
    }

    /**
     * which are the conditions met (particularly useful when in ERROR phase)
     */
    @com.fasterxml.jackson.annotation.JsonProperty("conditions")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("which are the conditions met (particularly useful when in ERROR phase)")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private java.util.List<org.apache.camel.v1.integrationprofilestatus.Conditions> conditions;

    public java.util.List<org.apache.camel.v1.integrationprofilestatus.Conditions> getConditions() {
        return conditions;
    }

    public void setConditions(java.util.List<org.apache.camel.v1.integrationprofilestatus.Conditions> conditions) {
        this.conditions = conditions;
    }

    /**
     * configuration to be executed to all Kamelets controlled by this IntegrationProfile
     */
    @com.fasterxml.jackson.annotation.JsonProperty("kamelet")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("configuration to be executed to all Kamelets controlled by this IntegrationProfile")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1.integrationprofilestatus.Kamelet kamelet;

    public org.apache.camel.v1.integrationprofilestatus.Kamelet getKamelet() {
        return kamelet;
    }

    public void setKamelet(org.apache.camel.v1.integrationprofilestatus.Kamelet kamelet) {
        this.kamelet = kamelet;
    }

    /**
     * ObservedGeneration is the most recent generation observed for this IntegrationProfile.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("observedGeneration")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("ObservedGeneration is the most recent generation observed for this IntegrationProfile.")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private Long observedGeneration;

    public Long getObservedGeneration() {
        return observedGeneration;
    }

    public void setObservedGeneration(Long observedGeneration) {
        this.observedGeneration = observedGeneration;
    }

    /**
     * defines in what phase the IntegrationProfile is found
     */
    @com.fasterxml.jackson.annotation.JsonProperty("phase")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("defines in what phase the IntegrationProfile is found")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private String phase;

    public String getPhase() {
        return phase;
    }

    public void setPhase(String phase) {
        this.phase = phase;
    }

    /**
     * list of traits to be executed for all the Integration/IntegrationKits built from this IntegrationProfile
     */
    @com.fasterxml.jackson.annotation.JsonProperty("traits")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("list of traits to be executed for all the Integration/IntegrationKits built from this IntegrationProfile")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1.integrationprofilestatus.Traits traits;

    public org.apache.camel.v1.integrationprofilestatus.Traits getTraits() {
        return traits;
    }

    public void setTraits(org.apache.camel.v1.integrationprofilestatus.Traits traits) {
        this.traits = traits;
    }
}
